# Changelog

## 0.2.0 (2024-10-07)

Full Changelog: [v0.0.1-alpha.0...v0.2.0](https://github.com/lastmile-ai/lastmile-python/compare/v0.0.1-alpha.0...v0.2.0)

### Features

* **api:** manual updates ([bef66b6](https://github.com/lastmile-ai/lastmile-python/commit/bef66b6d9b34c9bbdc682083670b7e72e26e63b3))
* **api:** manual updates ([71c6860](https://github.com/lastmile-ai/lastmile-python/commit/71c68603c7b6ee45798881cd74a255434c4600f5))
* **api:** manual updates ([a4976c3](https://github.com/lastmile-ai/lastmile-python/commit/a4976c3c4265c168347989a6776cb731bd788ec4))
* **api:** manual updates ([7d33740](https://github.com/lastmile-ai/lastmile-python/commit/7d3374067a08e0b2fb6f0c981b83a1924b9c5959))
* **api:** manual updates ([459013a](https://github.com/lastmile-ai/lastmile-python/commit/459013afded932da2ea506a5858f1ad2f5395ff1))
* **api:** manual updates ([ba9baeb](https://github.com/lastmile-ai/lastmile-python/commit/ba9baebe6cecacbc4a1da569b5a8141de5dd86b7))
* **api:** manual updates ([30b1d82](https://github.com/lastmile-ai/lastmile-python/commit/30b1d825b95a35f730affa9dce915e2e9607b502))
* **api:** manual updates ([353997c](https://github.com/lastmile-ai/lastmile-python/commit/353997c164e7bb24e6d04cbe745365b4a59a2e17))
* **api:** manual updates ([d41db01](https://github.com/lastmile-ai/lastmile-python/commit/d41db0146761bfea263c6a888f1efec8264d180a))
* **api:** manual updates ([c8587b0](https://github.com/lastmile-ai/lastmile-python/commit/c8587b04c6f86791103dcccf042176752fe2ddc1))
* **api:** manual updates ([#4](https://github.com/lastmile-ai/lastmile-python/issues/4)) ([cac7caf](https://github.com/lastmile-ai/lastmile-python/commit/cac7caf774f9f35a14632ed5a26fa295b52fbdd8))
* **api:** manual updates ([#5](https://github.com/lastmile-ai/lastmile-python/issues/5)) ([eb3ec90](https://github.com/lastmile-ai/lastmile-python/commit/eb3ec90416dcac5299db02d4cd89a5c01742da3d))


### Bug Fixes

* **client:** avoid OverflowError with very large retry counts ([#4](https://github.com/lastmile-ai/lastmile-python/issues/4)) ([47d0fb2](https://github.com/lastmile-ai/lastmile-python/commit/47d0fb29f89f32d6fe59ee16228ea934bd502216))


### Chores

* add repr to PageInfo class ([8d0dde1](https://github.com/lastmile-ai/lastmile-python/commit/8d0dde1480e1eff8a43c89b10ce9399789787411))
* go live ([#1](https://github.com/lastmile-ai/lastmile-python/issues/1)) ([d1a9313](https://github.com/lastmile-ai/lastmile-python/commit/d1a9313a1041302aa553a751b2db3a1777721e9a))
* go live ([#1](https://github.com/lastmile-ai/lastmile-python/issues/1)) ([9e6fc92](https://github.com/lastmile-ai/lastmile-python/commit/9e6fc92ebec5b9e78b2c18938d50583d825a0188))
* update SDK settings ([2eba47f](https://github.com/lastmile-ai/lastmile-python/commit/2eba47ffaf5a53c54ec945a60cfa3f08e47812a0))
* update SDK settings ([#3](https://github.com/lastmile-ai/lastmile-python/issues/3)) ([1d43bb0](https://github.com/lastmile-ai/lastmile-python/commit/1d43bb0bda7d80b970b051425be1ab4a844a246f))
* update SDK settings ([#3](https://github.com/lastmile-ai/lastmile-python/issues/3)) ([e63c99b](https://github.com/lastmile-ai/lastmile-python/commit/e63c99b3a52e8eb5dc90900f91c32d65b1a747f5))
